##
##  groff.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         groff
Summary:      GNU Roff Typesetting System
URL:          http://www.gnu.org/software/groff/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Typesetting
License:      GPL
Version:      1.23.0
Release:      20230708

#   list of sources
Source0:      http://ftp.gnu.org/gnu/groff/groff-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, gcc::with_cxx = yes, bison, texinfo, grep, ghostscript
PreReq:       OpenPKG, openpkg >= 20160101, perl, ghostscript

%description
    Groff (GNU Troff) is a document processor which reads plain text
    mixed with formatting commands and produces formatted output.

%track
    prog groff = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/groff/
        regex     = groff-(\d+\.\d+(\.\d+)*)\.tar\.gz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CXX="%{l_cxx}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    PERLPATH="%{l_prefix}/bin/perl" \
    %{l_bash} ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --without-x
    PATH="`pwd`/src/roff/troff:$PATH"
    PATH="`pwd`/src/roff/groff:$PATH"
    PATH="`pwd`/src/devices/grops:$PATH"
    PATH="`pwd`/workaround:$PATH"
    mkdir workaround
    for tool in xpmtoppm pnmdepth pnmtopng pnmtops; do
        ( echo "#!/bin/sh"
          echo "echo \"use of (non-existing) tool \\\"$tool\\\" disabled by OpenPKG\""
          echo "exit 0"
        ) >workaround/$tool
        chmod a+x workaround/$tool
    done
    %{l_make} %{l_mflags}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

